diff src/plugins/plugin_misc_text_commands.py @ 1199:96fb74a4714d

misc: fixed some typos
author Matteo Cypriani <mcy@lm7.fr>
date Mon, 15 Sep 2014 14:18:25 +0200
parents 0abce7f17782
children faa1129559b8
line wrap: on
line diff
--- a/src/plugins/plugin_misc_text_commands.py	Tue Sep 09 22:09:51 2014 -0400
+++ b/src/plugins/plugin_misc_text_commands.py	Mon Sep 15 14:18:25 2014 +0200
@@ -81,7 +81,7 @@
         """Add a callback which give information to the /whois command
         @param callback: a callback which will be called with the following arguments
             - whois_msg: list of information strings to display, callback need to append its own strings to it
-            - target_jid: full jid from who we want informations
+            - target_jid: full jid from whom we want information
             - profile: %(doc_profile)s
         @param priority: priority of the information to show (the highest priority will be displayed first)
 
@@ -184,7 +184,7 @@
         self.host.plugins[C.TEXT_CMDS].feedBack(feedback + self.HELP_SUGGESTION, mess_data, profile)
 
     def cmd_whois(self, mess_data, profile):
         """show informations on entity"""
         log.debug("Catched whois command")
 
         entity = mess_data["unparsed"].strip()
@@ -184,7 +184,7 @@
 
     def cmd_whois(self, mess_data, profile):
-        """show informations on entity"""
+        """show information on entity"""
         log.debug("Catched whois command")
 